/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_sgfXNhyC);
  numBytes += sLine_init(&sLine_4LL3vnUx);
  numBytes += sTabhead_init(&sTabhead_gIsU1qeC, &hTable_anIPIB2d);
  numBytes += sTabread_init(&sTabread_BxsMTn4q, &hTable_anIPIB2d, false);
  numBytes += sTabread_init(&sTabread_90XxC908, &hTable_anIPIB2d, false);
  numBytes += sLine_init(&sLine_SpRdOEEB);
  numBytes += sLine_init(&sLine_9DTCnvgs);
  numBytes += sLine_init(&sLine_iCJxqmzf);
  numBytes += sTabhead_init(&sTabhead_GH8V07DN, &hTable_gRa5j4Ve);
  numBytes += sTabread_init(&sTabread_D9SFHkq2, &hTable_gRa5j4Ve, false);
  numBytes += sTabread_init(&sTabread_eyJW73b5, &hTable_gRa5j4Ve, false);
  numBytes += sLine_init(&sLine_cD4tftey);
  numBytes += sTabwrite_init(&sTabwrite_khG8L18H, &hTable_anIPIB2d);
  numBytes += sTabwrite_init(&sTabwrite_zeYrAUCi, &hTable_gRa5j4Ve);
  numBytes += sRPole_init(&sRPole_kT9lywa1);
  numBytes += sRPole_init(&sRPole_tUwarmsj);
  numBytes += sRPole_init(&sRPole_qYePXL7D);
  numBytes += sDel1_init(&sDel1_U5Q3M7AJ);
  numBytes += sLine_init(&sLine_iZ2G02M5);
  numBytes += sLine_init(&sLine_aj2HMsu1);
  numBytes += sRPole_init(&sRPole_u94YoF37);
  numBytes += sRPole_init(&sRPole_P5HTNR4Q);
  numBytes += sRPole_init(&sRPole_lEz4Aszx);
  numBytes += sDel1_init(&sDel1_qfr4jcmt);
  numBytes += sLine_init(&sLine_EXlnkxs7);
  numBytes += sLine_init(&sLine_OyL7smJ7);
  numBytes += sLine_init(&sLine_RB3EvcfO);
  numBytes += sLine_init(&sLine_8ObWp3pe);
  numBytes += cVar_init_f(&cVar_r5OOWMqu, 0.0f);
  numBytes += cVar_init_f(&cVar_uJSPEzH1, 0.0f);
  numBytes += cVar_init_f(&cVar_VnrHYnA9, 0.0f);
  numBytes += cVar_init_f(&cVar_HX9kmYMY, 0.0f);
  numBytes += cSlice_init(&cSlice_zNhB1aw5, 1, -1);
  numBytes += cVar_init_f(&cVar_jbFIbSln, 0.5f);
  numBytes += cSlice_init(&cSlice_UvV1KF8k, 1, -1);
  numBytes += cVar_init_f(&cVar_9WhRxW08, 0.2f);
  numBytes += cSlice_init(&cSlice_1unBxwDr, 1, -1);
  numBytes += cVar_init_f(&cVar_Am6noTmt, 500.0f);
  numBytes += cSlice_init(&cSlice_c985E5dp, 1, -1);
  numBytes += cVar_init_f(&cVar_bTqVOhiL, 0.25f);
  numBytes += cDelay_init(this, &cDelay_GWF8EVjz, 0.0f);
  numBytes += cDelay_init(this, &cDelay_uoyQOeME, 0.0f);
  numBytes += hTable_init(&hTable_anIPIB2d, 256);
  numBytes += cDelay_init(this, &cDelay_TIFDulYm, 0.0f);
  numBytes += cDelay_init(this, &cDelay_UqICxxaY, 0.0f);
  numBytes += hTable_init(&hTable_gRa5j4Ve, 256);
  numBytes += cVar_init_f(&cVar_GZJSeNaL, 8000.0f);
  numBytes += cBinop_init(&cBinop_wTQeA6vI, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_XkvsjDrq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CO65uQjV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_pHNryVxW, 8000.0f);
  numBytes += cBinop_init(&cBinop_WNUvjCVB, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6hlxPyJ0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5wYBTmRq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qce5h8rM, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_P4eUfu6a, 300.0f);
  numBytes += cBinop_init(&cBinop_idESKi0q, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_pvlQNC6J, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_PQPLFv6y, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_olzPTYud, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Y4S4ioFT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ii8n4xED, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_XslPNJu1, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_RU0kxEV5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_h4cnvXAB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YD2hdcQx, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Tv5bBzba, 8000.0f);
  numBytes += cBinop_init(&cBinop_alY75bLO, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_nxBGMd6w, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zGdYRrDk, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_DR819JQV, 8000.0f);
  numBytes += cBinop_init(&cBinop_X2zM9Zz3, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ij38Bw2n, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ye2FizxG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XQqLNfOy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Xt0GD7ZR, 300.0f);
  numBytes += cBinop_init(&cBinop_29gVqxfu, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_5NfYJKCC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cpTnlt9Q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_g1BJqHU2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_alqAsq3P, 1.0f);
  numBytes += cIf_init(&cIf_HKkNoRsO, false);
  numBytes += cIf_init(&cIf_Vxv9SuaD, false);
  numBytes += cVar_init_f(&cVar_05fKgThd, 0.0f);
  numBytes += cVar_init_f(&cVar_SHoisQT8, 0.0f);
  numBytes += cVar_init_f(&cVar_aTI8YrCY, 60000.0f);
  numBytes += cVar_init_f(&cVar_0uvBUTDv, 500.0f);
  numBytes += cSlice_init(&cSlice_ps8gVroA, 1, -1);
  numBytes += cSlice_init(&cSlice_abj75fg2, 1, -1);
  numBytes += cVar_init_f(&cVar_q7DfQNol, 0.0f);
  numBytes += cIf_init(&cIf_IwASzDK9, false);
  numBytes += cBinop_init(&cBinop_5HPdSS8E, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_kONrBtJX, 120.0f);
  numBytes += cBinop_init(&cBinop_CGrOzdXm, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_kXdREMC1, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_anIPIB2d);
  hTable_free(&hTable_gRa5j4Ve);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_anIPIB2d; // del-1011-delayL
    case 0xF057CB49: return &hTable_gRa5j4Ve; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sW1CmJ2l_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SA4Gq782_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0pyUrZAL_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yBZjTBBh_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WUcih1hH_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RKN3bn1J_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S4ywm7io_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wlMAfleX_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5Rs0X0VW_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rwB2eTk8_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UH6PDfqz_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P28b4HbX_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_r5OOWMqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mXp8Udvf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_uJSPEzH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_owznoFqZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_VnrHYnA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_63s5t63J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_HX9kmYMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DJy5mUjI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_pWwK8OXo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zNhB1aw5, 0, m, &cSlice_zNhB1aw5_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_zNhB1aw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zP0MdZI8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zP0MdZI8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_jbFIbSln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zP0MdZI8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_zP0MdZI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5Rs0X0VW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_gOSv6ViT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UvV1KF8k, 0, m, &cSlice_UvV1KF8k_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pIcrbYcM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_UvV1KF8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_p4lVWA9H_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_p4lVWA9H_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_9WhRxW08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_p4lVWA9H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_p4lVWA9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_S4ywm7io_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_GOErBUOB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1unBxwDr, 0, m, &cSlice_1unBxwDr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pWwK8OXo_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_1unBxwDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_m80Hpqe4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_m80Hpqe4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_Am6noTmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m80Hpqe4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_m80Hpqe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rwB2eTk8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_zaWFlwoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_JPfQ7rFZ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JPfQ7rFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_b7r6Kclm_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_QkPOprG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4bobgmtE_sendMessage(_c, 0, m);
  cMsg_fhAPmgld_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_nUlSPwYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M6d7g1yL_sendMessage(_c, 0, m);
  cMsg_I7QVRmFU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_b7r6Kclm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_AypJYiKz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_AypJYiKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8nrz8VTN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A0FciC6f_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_A0FciC6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VpzClBry_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_8nrz8VTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kMWHllLn_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_kMWHllLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7U6RT2y8_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_VpzClBry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_usLILK9j_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_usLILK9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_La4hTjbv_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7U6RT2y8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_QkPOprG0_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_La4hTjbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_nUlSPwYA_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Z7G3tvUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TYsJirVp_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_TYsJirVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_3CJ8kDdu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_3CJ8kDdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_MiKcHITE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_MiKcHITE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_argX6egq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RRaA8GTJ_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_RRaA8GTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vkPnOhNC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_argX6egq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_F9PcI89E_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_F9PcI89E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RinhcCTB_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_vkPnOhNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1pZLmkbS_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_1pZLmkbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Oq8antMW_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Oq8antMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wD4SuCQz_sendMessage(_c, 0, m);
  cMsg_bO5IBkVq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_RinhcCTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dcmawnma_sendMessage(_c, 0, m);
  cMsg_RhaIv1tc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_pIcrbYcM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_c985E5dp, 0, m, &cSlice_c985E5dp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GOErBUOB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_c985E5dp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_p8Kxd67b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_p8Kxd67b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_bTqVOhiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_p8Kxd67b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_p8Kxd67b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wlMAfleX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_4iK2uIvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_g2cVsQ1k_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_g2cVsQ1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_o9teiwni_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_GWF8EVjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GWF8EVjz, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uoyQOeME, 0, m, &cDelay_uoyQOeME_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GWF8EVjz, 0, m, &cDelay_GWF8EVjz_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_khG8L18H, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_uoyQOeME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uoyQOeME, m);
  cMsg_qmPDpxmG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_boNkQW1m_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_6AdpBZAp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_Zo6qlhBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KuhU1QJj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_anIPIB2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d4W53CzD_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GWF8EVjz, 2, m, &cDelay_GWF8EVjz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UVG2h953_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_KuhU1QJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_anIPIB2d, 0, m, &hTable_anIPIB2d_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_o9teiwni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Zo6qlhBD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_qmPDpxmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_anIPIB2d, 0, m, &hTable_anIPIB2d_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_UVG2h953_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GWF8EVjz, 0, m, &cDelay_GWF8EVjz_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_d4W53CzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_uoyQOeME, 2, m, &cDelay_uoyQOeME_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_6AdpBZAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_khG8L18H, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_o8TBY1gM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xlx0EUdz_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_Xlx0EUdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0Gr0ef2a_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_TIFDulYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TIFDulYm, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UqICxxaY, 0, m, &cDelay_UqICxxaY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TIFDulYm, 0, m, &cDelay_TIFDulYm_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_zeYrAUCi, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_UqICxxaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UqICxxaY, m);
  cMsg_BDz1mY40_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_mDLmbEVa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ro8QId6N_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_Kb7YbdMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ya64Tzms_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_gRa5j4Ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_79v4iVZh_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TIFDulYm, 2, m, &cDelay_TIFDulYm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YdQFP5OB_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ya64Tzms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_gRa5j4Ve, 0, m, &hTable_gRa5j4Ve_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_0Gr0ef2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Kb7YbdMO_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_BDz1mY40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_gRa5j4Ve, 0, m, &hTable_gRa5j4Ve_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_YdQFP5OB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TIFDulYm, 0, m, &cDelay_TIFDulYm_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_79v4iVZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_UqICxxaY, 2, m, &cDelay_UqICxxaY_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ro8QId6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_zeYrAUCi, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_GZJSeNaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wTQeA6vI, HV_BINOP_MULTIPLY, 0, m, &cBinop_wTQeA6vI_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_s8AoAWC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7rVZiWay_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_7rVZiWay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BVYYiUkA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_wTQeA6vI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JwWfGddq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ptF27FPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wTQeA6vI, HV_BINOP_MULTIPLY, 1, m, &cBinop_wTQeA6vI_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_BVYYiUkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ptF27FPS_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JwWfGddq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_UXqobAoB_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_UXqobAoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_TaSAhD5P_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CO65uQjV, m);
}

void Heavy_WSTD_DLAY::cBinop_TaSAhD5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XkvsjDrq, m);
}

void Heavy_WSTD_DLAY::cVar_pHNryVxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WNUvjCVB, HV_BINOP_MULTIPLY, 0, m, &cBinop_WNUvjCVB_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_V11sAEDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dmx6BCEM_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_dmx6BCEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IJVvrxv8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_WNUvjCVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ChQtLNL1_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_bxOQbSk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WNUvjCVB, HV_BINOP_MULTIPLY, 1, m, &cBinop_WNUvjCVB_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_IJVvrxv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bxOQbSk3_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ChQtLNL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2Q90L6Fw_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_2Q90L6Fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_lOSCzgtq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5wYBTmRq, m);
}

void Heavy_WSTD_DLAY::cBinop_lOSCzgtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6hlxPyJ0, m);
}

void Heavy_WSTD_DLAY::cBinop_zZgIzgbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_A2zK4YMf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_A2zK4YMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RcqqQCMB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PeKfkuPn_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_P4eUfu6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_s3yerRb3_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_MVqoz9NL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eiGqXykI_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_eiGqXykI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_idESKi0q, HV_BINOP_DIVIDE, 1, m, &cBinop_idESKi0q_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_RcqqQCMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4ilfwIzP_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4ilfwIzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pvlQNC6J, m);
}

void Heavy_WSTD_DLAY::cMsg_5JUIvKTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_IEKj7iD5_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_IEKj7iD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zZgIzgbK_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_PeKfkuPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qce5h8rM, m);
}

void Heavy_WSTD_DLAY::cBinop_s3yerRb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_axB70qyZ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_axB70qyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_idESKi0q, HV_BINOP_DIVIDE, 0, m, &cBinop_idESKi0q_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_idESKi0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5JUIvKTZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_XtCwyhTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UW24YzlY_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_UW24YzlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Nf26Kg7T_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_PQPLFv6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lqBSCMuy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_p1ocaZ2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_w6vyJhsX_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_olzPTYud, m);
}

void Heavy_WSTD_DLAY::cBinop_Nf26Kg7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Y4S4ioFT, m);
}

void Heavy_WSTD_DLAY::cMsg_lqBSCMuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_p1ocaZ2L_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_w6vyJhsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ii8n4xED, m);
}

void Heavy_WSTD_DLAY::cMsg_vmXgFLfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pkxLTncZ_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_pkxLTncZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cVAjxvP3_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_XslPNJu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yb5yKPty_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_FbTD8KAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9J9mJ5eg_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_RU0kxEV5, m);
}

void Heavy_WSTD_DLAY::cBinop_cVAjxvP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_h4cnvXAB, m);
}

void Heavy_WSTD_DLAY::cMsg_yb5yKPty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FbTD8KAO_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_9J9mJ5eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_YD2hdcQx, m);
}

void Heavy_WSTD_DLAY::cVar_Tv5bBzba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_alY75bLO, HV_BINOP_MULTIPLY, 0, m, &cBinop_alY75bLO_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_9Alguf6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bHP0MeFx_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_bHP0MeFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_laxpHHW8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_alY75bLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YzBbWr2E_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_MFoU4FHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_alY75bLO, HV_BINOP_MULTIPLY, 1, m, &cBinop_alY75bLO_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_laxpHHW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MFoU4FHd_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_YzBbWr2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zCkjf51O_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_zCkjf51O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_CiSesRoc_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zGdYRrDk, m);
}

void Heavy_WSTD_DLAY::cBinop_CiSesRoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nxBGMd6w, m);
}

void Heavy_WSTD_DLAY::cVar_DR819JQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X2zM9Zz3, HV_BINOP_MULTIPLY, 0, m, &cBinop_X2zM9Zz3_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_eqySscMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8fu5GhLa_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_8fu5GhLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RnhlGP8U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_X2zM9Zz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3iwVslbm_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HpTw8aXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X2zM9Zz3, HV_BINOP_MULTIPLY, 1, m, &cBinop_X2zM9Zz3_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_RnhlGP8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HpTw8aXQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_3iwVslbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_VbYfhLSo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_VbYfhLSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rbYSLu0j_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ye2FizxG, m);
}

void Heavy_WSTD_DLAY::cBinop_rbYSLu0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ij38Bw2n, m);
}

void Heavy_WSTD_DLAY::cBinop_pY2kJVCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_1vB6s7o7_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_1vB6s7o7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Bq9MewnF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_m7YPTqxu_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_Xt0GD7ZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_n4cXrnyj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_M2je6Uku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_14UUpfEn_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_14UUpfEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_29gVqxfu, HV_BINOP_DIVIDE, 1, m, &cBinop_29gVqxfu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Bq9MewnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9kRr4AOz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_9kRr4AOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5NfYJKCC, m);
}

void Heavy_WSTD_DLAY::cMsg_6mOvqTlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JTyOp8e6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JTyOp8e6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pY2kJVCr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_m7YPTqxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XQqLNfOy, m);
}

void Heavy_WSTD_DLAY::cBinop_n4cXrnyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_kSNISaMP_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_kSNISaMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_29gVqxfu, HV_BINOP_DIVIDE, 0, m, &cBinop_29gVqxfu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_29gVqxfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6mOvqTlt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_4bobgmtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SpRdOEEB, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_M6d7g1yL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sgfXNhyC, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_I7QVRmFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9DTCnvgs, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_fhAPmgld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cD4tftey, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_RhaIv1tc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OyL7smJ7, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_wD4SuCQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aj2HMsu1, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Dcmawnma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8ObWp3pe, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_bO5IBkVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RB3EvcfO, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_4YoZh7IT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4LL3vnUx, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_7IRVQAxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iCJxqmzf, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_YdgPAgBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iZ2G02M5, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_ci18jswm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EXlnkxs7, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_alqAsq3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aiRTMjM6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7TZbdgw6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CjURJwPc_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_aiRTMjM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_alqAsq3P, 1, m, &cVar_alqAsq3P_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_HKkNoRsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_uJSPEzH1, 0, m, &cVar_uJSPEzH1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_Vxv9SuaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_uJSPEzH1, 0, m, &cVar_uJSPEzH1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_05fKgThd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vxv9SuaD, 0, m, &cIf_Vxv9SuaD_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_SHoisQT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HKkNoRsO, 0, m, &cIf_HKkNoRsO_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_aTI8YrCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CGrOzdXm, HV_BINOP_DIVIDE, 0, m, &cBinop_CGrOzdXm_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_0uvBUTDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kXdREMC1, HV_BINOP_MULTIPLY, 1, m, &cBinop_kXdREMC1_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_713hD9LJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ps8gVroA, 0, m, &cSlice_ps8gVroA_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_abj75fg2, 0, m, &cSlice_abj75fg2_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BcIxPYx6_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7mmH6Zeu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_ps8gVroA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_q7DfQNol, 0, m, &cVar_q7DfQNol_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_q7DfQNol, 0, m, &cVar_q7DfQNol_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_abj75fg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5HPdSS8E, HV_BINOP_NEQ, 1, m, &cBinop_5HPdSS8E_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_q7DfQNol, 1, m, &cVar_q7DfQNol_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5HPdSS8E, HV_BINOP_NEQ, 1, m, &cBinop_5HPdSS8E_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_q7DfQNol, 1, m, &cVar_q7DfQNol_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_q7DfQNol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_ExI0U0eI_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_IwASzDK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Oz0gCcSp_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0Fh358do_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_0Fh358do_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_q7DfQNol, 0, m, &cVar_q7DfQNol_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Oz0gCcSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5HPdSS8E, HV_BINOP_NEQ, 1, m, &cBinop_5HPdSS8E_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_5HPdSS8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IwASzDK9, 1, m, &cIf_IwASzDK9_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_7mmH6Zeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IwASzDK9, 0, m, &cIf_IwASzDK9_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_BcIxPYx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5HPdSS8E, HV_BINOP_NEQ, 0, m, &cBinop_5HPdSS8E_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_kONrBtJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7YoIvHF3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3xDAMJ9c_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_rEqrqwt4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hrkFLkAP_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XGNvWl8l_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DpMwe9K4_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bNyNBOjF_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xhGoiFGu_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hP4snDxs_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h4FQ7pSX_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1EINAiIo_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t3ZXiVwf_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aVuatS5p_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sEd6N7Yo_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O2L4CQ1Z_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mfuIaDoT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_hrkFLkAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zWpa8TdI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_XGNvWl8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2if5XCE8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_DpMwe9K4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kAscWGMX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_bNyNBOjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8BU2qRci_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_xhGoiFGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xBPz9vcl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_hP4snDxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6PCvWs72_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_h4FQ7pSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cjFKTti4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_1EINAiIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YLuPLzFX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_t3ZXiVwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_INfmh106_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_aVuatS5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2I4gfzin_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_sEd6N7Yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Hh0v9ec_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_O2L4CQ1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LT4uRb5b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_mfuIaDoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ak9ISSs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_CGrOzdXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kXdREMC1, HV_BINOP_MULTIPLY, 0, m, &cBinop_kXdREMC1_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_kXdREMC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_713hD9LJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_3xDAMJ9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aTI8YrCY, 0, m, &cVar_aTI8YrCY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0uvBUTDv, 0, m, &cVar_0uvBUTDv_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_7YoIvHF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CGrOzdXm, HV_BINOP_DIVIDE, 1, m, &cBinop_CGrOzdXm_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_1PRP1Xsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0uvBUTDv, 0, m, &cVar_0uvBUTDv_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_tMFVnIQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aTI8YrCY, 0, m, &cVar_aTI8YrCY_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_zWpa8TdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2if5XCE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_kAscWGMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_8BU2qRci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_xBPz9vcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_6PCvWs72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_cjFKTti4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_YLuPLzFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_INfmh106_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2I4gfzin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_5Hh0v9ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_LT4uRb5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2ak9ISSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PRP1Xsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tMFVnIQP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_DJy5mUjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_gOSv6ViT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_mXp8Udvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_gOSv6ViT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_GSiEaIX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HX9kmYMY, 0, m, &cVar_HX9kmYMY_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_BgiqYFk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r5OOWMqu, 0, m, &cVar_r5OOWMqu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_nQZgjBCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VnrHYnA9, 0, m, &cVar_VnrHYnA9_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_owznoFqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_gOSv6ViT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_63s5t63J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_gOSv6ViT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_ExI0U0eI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SHoisQT8, 0, m, &cVar_SHoisQT8_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_CjURJwPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SKFMGxtj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9An3yPZu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7TZbdgw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5XNz3Xq2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fmxE1ou6_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_fmxE1ou6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_05fKgThd, 0, m, &cVar_05fKgThd_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_5XNz3Xq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vxv9SuaD, 1, m, &cIf_Vxv9SuaD_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_SKFMGxtj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HKkNoRsO, 1, m, &cIf_HKkNoRsO_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_9An3yPZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SHoisQT8, 0, m, &cVar_SHoisQT8_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_0pyUrZAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_GSiEaIX7_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_SA4Gq782_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_BgiqYFk3_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_sW1CmJ2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_nQZgjBCm_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_WUcih1hH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_05fKgThd, 0, m, &cVar_05fKgThd_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_rwB2eTk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4YoZh7IT_sendMessage(_c, 0, m);
  cMsg_7IRVQAxj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_wlMAfleX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YdgPAgBB_sendMessage(_c, 0, m);
  cMsg_ci18jswm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_5Rs0X0VW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zaWFlwoi_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_P28b4HbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jbFIbSln, 0, m, &cVar_jbFIbSln_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9WhRxW08, 0, m, &cVar_9WhRxW08_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Am6noTmt, 0, m, &cVar_Am6noTmt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bTqVOhiL, 0, m, &cVar_bTqVOhiL_sendMessage);
  cMsg_4iK2uIvn_sendMessage(_c, 0, m);
  cMsg_o8TBY1gM_sendMessage(_c, 0, m);
  cMsg_s8AoAWC9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GZJSeNaL, 0, m, &cVar_GZJSeNaL_sendMessage);
  cMsg_V11sAEDg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pHNryVxW, 0, m, &cVar_pHNryVxW_sendMessage);
  cMsg_MVqoz9NL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_P4eUfu6a, 0, m, &cVar_P4eUfu6a_sendMessage);
  cMsg_9Alguf6H_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Tv5bBzba, 0, m, &cVar_Tv5bBzba_sendMessage);
  cMsg_eqySscMH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DR819JQV, 0, m, &cVar_DR819JQV_sendMessage);
  cMsg_M2je6Uku_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Xt0GD7ZR, 0, m, &cVar_Xt0GD7ZR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PQPLFv6y, 0, m, &cVar_PQPLFv6y_sendMessage);
  cMsg_XtCwyhTD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XslPNJu1, 0, m, &cVar_XslPNJu1_sendMessage);
  cMsg_vmXgFLfy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_S4ywm7io_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Z7G3tvUw_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_yBZjTBBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_alqAsq3P, 0, m, &cVar_alqAsq3P_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_UH6PDfqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kONrBtJX, 0, m, &cVar_kONrBtJX_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_RKN3bn1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rEqrqwt4_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_sgfXNhyC, VOf(Bf0));
    __hv_line_f(&sLine_4LL3vnUx, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_gIsU1qeC, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_Y4S4ioFT, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Ii8n4xED, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_olzPTYud, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_BxsMTn4q, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_90XxC908, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_SpRdOEEB, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_9DTCnvgs, VOf(Bf0));
    __hv_line_f(&sLine_iCJxqmzf, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_GH8V07DN, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_h4cnvXAB, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_YD2hdcQx, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_RU0kxEV5, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_D9SFHkq2, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_eyJW73b5, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_cD4tftey, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_cpTnlt9Q, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_khG8L18H, VIf(Bf0));
    __hv_varread_f(&sVarf_g1BJqHU2, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_zeYrAUCi, VIf(Bf0));
    __hv_varread_f(&sVarf_CO65uQjV, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_XkvsjDrq, VOf(Bf1));
    __hv_rpole_f(&sRPole_kT9lywa1, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_5wYBTmRq, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_6hlxPyJ0, VOf(Bf1));
    __hv_rpole_f(&sRPole_tUwarmsj, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_qce5h8rM, VOf(Bf0));
    __hv_rpole_f(&sRPole_qYePXL7D, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_U5Q3M7AJ, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_pvlQNC6J, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_iZ2G02M5, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_aj2HMsu1, VOf(Bf0));
    __hv_varread_f(&sVarf_zGdYRrDk, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_nxBGMd6w, VOf(Bf4));
    __hv_rpole_f(&sRPole_u94YoF37, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_ye2FizxG, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_ij38Bw2n, VOf(Bf4));
    __hv_rpole_f(&sRPole_P5HTNR4Q, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_XQqLNfOy, VOf(Bf6));
    __hv_rpole_f(&sRPole_lEz4Aszx, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_qfr4jcmt, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_5NfYJKCC, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_EXlnkxs7, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_OyL7smJ7, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_cpTnlt9Q, VIf(Bf6));
    __hv_line_f(&sLine_RB3EvcfO, VOf(Bf6));
    __hv_line_f(&sLine_8ObWp3pe, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_g1BJqHU2, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
