/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalVar.h"
#include "HvTable.h"
#include "HvSignalDel1.h"
#include "HvControlUnop.h"
#include "HvControlVar.h"
#include "HvSignalRPole.h"
#include "HvControlDelay.h"
#include "HvSignalLine.h"
#include "HvControlIf.h"
#include "HvControlSlice.h"
#include "HvMath.h"
#include "HvSignalTabread.h"
#include "HvControlSystem.h"
#include "HvControlBinop.h"
#include "HvControlCast.h"
#include "HvSignalTabwrite.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_r5OOWMqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uJSPEzH1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VnrHYnA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HX9kmYMY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pWwK8OXo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zNhB1aw5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jbFIbSln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zP0MdZI8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gOSv6ViT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_UvV1KF8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9WhRxW08_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_p4lVWA9H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GOErBUOB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_1unBxwDr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Am6noTmt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_m80Hpqe4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zaWFlwoi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JPfQ7rFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QkPOprG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nUlSPwYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b7r6Kclm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AypJYiKz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A0FciC6f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8nrz8VTN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kMWHllLn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VpzClBry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_usLILK9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7U6RT2y8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_La4hTjbv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z7G3tvUw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TYsJirVp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3CJ8kDdu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MiKcHITE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RRaA8GTJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_argX6egq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F9PcI89E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vkPnOhNC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1pZLmkbS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Oq8antMW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RinhcCTB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pIcrbYcM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_c985E5dp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bTqVOhiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_p8Kxd67b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4iK2uIvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_g2cVsQ1k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GWF8EVjz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_uoyQOeME_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_boNkQW1m_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Zo6qlhBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_anIPIB2d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KuhU1QJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o9teiwni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qmPDpxmG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UVG2h953_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d4W53CzD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6AdpBZAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o8TBY1gM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Xlx0EUdz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TIFDulYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UqICxxaY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mDLmbEVa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Kb7YbdMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_gRa5j4Ve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ya64Tzms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0Gr0ef2a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BDz1mY40_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YdQFP5OB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_79v4iVZh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ro8QId6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GZJSeNaL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s8AoAWC9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7rVZiWay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wTQeA6vI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ptF27FPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BVYYiUkA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JwWfGddq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UXqobAoB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TaSAhD5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pHNryVxW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V11sAEDg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dmx6BCEM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WNUvjCVB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bxOQbSk3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IJVvrxv8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ChQtLNL1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Q90L6Fw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lOSCzgtq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zZgIzgbK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A2zK4YMf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_P4eUfu6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MVqoz9NL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eiGqXykI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RcqqQCMB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4ilfwIzP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5JUIvKTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IEKj7iD5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PeKfkuPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s3yerRb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_axB70qyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_idESKi0q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XtCwyhTD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UW24YzlY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PQPLFv6y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_p1ocaZ2L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nf26Kg7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lqBSCMuy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w6vyJhsX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vmXgFLfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pkxLTncZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XslPNJu1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FbTD8KAO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cVAjxvP3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yb5yKPty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9J9mJ5eg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Tv5bBzba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9Alguf6H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bHP0MeFx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_alY75bLO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MFoU4FHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_laxpHHW8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YzBbWr2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zCkjf51O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CiSesRoc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DR819JQV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eqySscMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8fu5GhLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X2zM9Zz3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HpTw8aXQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RnhlGP8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3iwVslbm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VbYfhLSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rbYSLu0j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pY2kJVCr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1vB6s7o7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Xt0GD7ZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M2je6Uku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_14UUpfEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bq9MewnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9kRr4AOz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6mOvqTlt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JTyOp8e6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m7YPTqxu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n4cXrnyj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kSNISaMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_29gVqxfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4bobgmtE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M6d7g1yL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I7QVRmFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fhAPmgld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RhaIv1tc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wD4SuCQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dcmawnma_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bO5IBkVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4YoZh7IT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7IRVQAxj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YdgPAgBB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ci18jswm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_alqAsq3P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aiRTMjM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HKkNoRsO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Vxv9SuaD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_05fKgThd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SHoisQT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aTI8YrCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0uvBUTDv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_713hD9LJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ps8gVroA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_abj75fg2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_q7DfQNol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IwASzDK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0Fh358do_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Oz0gCcSp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5HPdSS8E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7mmH6Zeu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BcIxPYx6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kONrBtJX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rEqrqwt4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_hrkFLkAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XGNvWl8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DpMwe9K4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bNyNBOjF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xhGoiFGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hP4snDxs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h4FQ7pSX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1EINAiIo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t3ZXiVwf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aVuatS5p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sEd6N7Yo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O2L4CQ1Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mfuIaDoT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CGrOzdXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kXdREMC1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3xDAMJ9c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7YoIvHF3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1PRP1Xsh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tMFVnIQP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zWpa8TdI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2if5XCE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kAscWGMX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8BU2qRci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xBPz9vcl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6PCvWs72_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cjFKTti4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YLuPLzFX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_INfmh106_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2I4gfzin_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5Hh0v9ec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LT4uRb5b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2ak9ISSs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DJy5mUjI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mXp8Udvf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GSiEaIX7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BgiqYFk3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nQZgjBCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_owznoFqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_63s5t63J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ExI0U0eI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CjURJwPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7TZbdgw6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fmxE1ou6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5XNz3Xq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SKFMGxtj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9An3yPZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0pyUrZAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SA4Gq782_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sW1CmJ2l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WUcih1hH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rwB2eTk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wlMAfleX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5Rs0X0VW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P28b4HbX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_S4ywm7io_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yBZjTBBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UH6PDfqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RKN3bn1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_sgfXNhyC;
  SignalLine sLine_4LL3vnUx;
  SignalTabhead sTabhead_gIsU1qeC;
  SignalTabread sTabread_BxsMTn4q;
  SignalTabread sTabread_90XxC908;
  SignalLine sLine_SpRdOEEB;
  SignalLine sLine_9DTCnvgs;
  SignalLine sLine_iCJxqmzf;
  SignalTabhead sTabhead_GH8V07DN;
  SignalTabread sTabread_D9SFHkq2;
  SignalTabread sTabread_eyJW73b5;
  SignalLine sLine_cD4tftey;
  SignalTabwrite sTabwrite_khG8L18H;
  SignalTabwrite sTabwrite_zeYrAUCi;
  SignalRPole sRPole_kT9lywa1;
  SignalRPole sRPole_tUwarmsj;
  SignalRPole sRPole_qYePXL7D;
  SignalDel1 sDel1_U5Q3M7AJ;
  SignalLine sLine_iZ2G02M5;
  SignalLine sLine_aj2HMsu1;
  SignalRPole sRPole_u94YoF37;
  SignalRPole sRPole_P5HTNR4Q;
  SignalRPole sRPole_lEz4Aszx;
  SignalDel1 sDel1_qfr4jcmt;
  SignalLine sLine_EXlnkxs7;
  SignalLine sLine_OyL7smJ7;
  SignalLine sLine_RB3EvcfO;
  SignalLine sLine_8ObWp3pe;
  ControlVar cVar_r5OOWMqu;
  ControlVar cVar_uJSPEzH1;
  ControlVar cVar_VnrHYnA9;
  ControlVar cVar_HX9kmYMY;
  ControlSlice cSlice_zNhB1aw5;
  ControlVar cVar_jbFIbSln;
  ControlSlice cSlice_UvV1KF8k;
  ControlVar cVar_9WhRxW08;
  ControlSlice cSlice_1unBxwDr;
  ControlVar cVar_Am6noTmt;
  ControlBinop cBinop_zaWFlwoi;
  ControlBinop cBinop_JPfQ7rFZ;
  ControlBinop cBinop_b7r6Kclm;
  ControlBinop cBinop_AypJYiKz;
  ControlBinop cBinop_kMWHllLn;
  ControlBinop cBinop_usLILK9j;
  ControlBinop cBinop_7U6RT2y8;
  ControlBinop cBinop_La4hTjbv;
  ControlBinop cBinop_Z7G3tvUw;
  ControlBinop cBinop_TYsJirVp;
  ControlBinop cBinop_3CJ8kDdu;
  ControlBinop cBinop_MiKcHITE;
  ControlBinop cBinop_F9PcI89E;
  ControlBinop cBinop_1pZLmkbS;
  ControlBinop cBinop_Oq8antMW;
  ControlBinop cBinop_RinhcCTB;
  ControlSlice cSlice_c985E5dp;
  ControlVar cVar_bTqVOhiL;
  ControlDelay cDelay_GWF8EVjz;
  ControlDelay cDelay_uoyQOeME;
  ControlBinop cBinop_Zo6qlhBD;
  HvTable hTable_anIPIB2d;
  ControlBinop cBinop_o9teiwni;
  ControlDelay cDelay_TIFDulYm;
  ControlDelay cDelay_UqICxxaY;
  ControlBinop cBinop_Kb7YbdMO;
  HvTable hTable_gRa5j4Ve;
  ControlBinop cBinop_0Gr0ef2a;
  ControlVar cVar_GZJSeNaL;
  ControlBinop cBinop_wTQeA6vI;
  ControlBinop cBinop_ptF27FPS;
  SignalVarf sVarf_XkvsjDrq;
  ControlBinop cBinop_JwWfGddq;
  ControlBinop cBinop_UXqobAoB;
  ControlBinop cBinop_TaSAhD5P;
  SignalVarf sVarf_CO65uQjV;
  ControlVar cVar_pHNryVxW;
  ControlBinop cBinop_WNUvjCVB;
  ControlBinop cBinop_bxOQbSk3;
  SignalVarf sVarf_6hlxPyJ0;
  ControlBinop cBinop_ChQtLNL1;
  ControlBinop cBinop_2Q90L6Fw;
  ControlBinop cBinop_lOSCzgtq;
  SignalVarf sVarf_5wYBTmRq;
  ControlBinop cBinop_zZgIzgbK;
  ControlBinop cBinop_A2zK4YMf;
  SignalVarf sVarf_qce5h8rM;
  ControlVar cVar_P4eUfu6a;
  ControlBinop cBinop_RcqqQCMB;
  ControlBinop cBinop_4ilfwIzP;
  ControlBinop cBinop_IEKj7iD5;
  ControlBinop cBinop_PeKfkuPn;
  ControlBinop cBinop_s3yerRb3;
  ControlBinop cBinop_axB70qyZ;
  ControlBinop cBinop_idESKi0q;
  SignalVarf sVarf_pvlQNC6J;
  ControlVar cVar_PQPLFv6y;
  ControlBinop cBinop_Nf26Kg7T;
  ControlBinop cBinop_w6vyJhsX;
  SignalVarf sVarf_olzPTYud;
  SignalVarf sVarf_Y4S4ioFT;
  SignalVarf sVarf_Ii8n4xED;
  ControlVar cVar_XslPNJu1;
  ControlBinop cBinop_cVAjxvP3;
  ControlBinop cBinop_9J9mJ5eg;
  SignalVarf sVarf_RU0kxEV5;
  SignalVarf sVarf_h4cnvXAB;
  SignalVarf sVarf_YD2hdcQx;
  ControlVar cVar_Tv5bBzba;
  ControlBinop cBinop_alY75bLO;
  ControlBinop cBinop_MFoU4FHd;
  SignalVarf sVarf_nxBGMd6w;
  ControlBinop cBinop_YzBbWr2E;
  ControlBinop cBinop_zCkjf51O;
  ControlBinop cBinop_CiSesRoc;
  SignalVarf sVarf_zGdYRrDk;
  ControlVar cVar_DR819JQV;
  ControlBinop cBinop_X2zM9Zz3;
  ControlBinop cBinop_HpTw8aXQ;
  SignalVarf sVarf_ij38Bw2n;
  ControlBinop cBinop_3iwVslbm;
  ControlBinop cBinop_VbYfhLSo;
  ControlBinop cBinop_rbYSLu0j;
  SignalVarf sVarf_ye2FizxG;
  ControlBinop cBinop_pY2kJVCr;
  ControlBinop cBinop_1vB6s7o7;
  SignalVarf sVarf_XQqLNfOy;
  ControlVar cVar_Xt0GD7ZR;
  ControlBinop cBinop_Bq9MewnF;
  ControlBinop cBinop_9kRr4AOz;
  ControlBinop cBinop_JTyOp8e6;
  ControlBinop cBinop_m7YPTqxu;
  ControlBinop cBinop_n4cXrnyj;
  ControlBinop cBinop_kSNISaMP;
  ControlBinop cBinop_29gVqxfu;
  SignalVarf sVarf_5NfYJKCC;
  SignalVarf sVarf_cpTnlt9Q;
  SignalVarf sVarf_g1BJqHU2;
  ControlVar cVar_alqAsq3P;
  ControlBinop cBinop_aiRTMjM6;
  ControlIf cIf_HKkNoRsO;
  ControlIf cIf_Vxv9SuaD;
  ControlVar cVar_05fKgThd;
  ControlVar cVar_SHoisQT8;
  ControlVar cVar_aTI8YrCY;
  ControlVar cVar_0uvBUTDv;
  ControlSlice cSlice_ps8gVroA;
  ControlSlice cSlice_abj75fg2;
  ControlVar cVar_q7DfQNol;
  ControlIf cIf_IwASzDK9;
  ControlBinop cBinop_5HPdSS8E;
  ControlVar cVar_kONrBtJX;
  ControlBinop cBinop_CGrOzdXm;
  ControlBinop cBinop_kXdREMC1;
  ControlBinop cBinop_GSiEaIX7;
  ControlBinop cBinop_BgiqYFk3;
  ControlBinop cBinop_nQZgjBCm;
  ControlBinop cBinop_ExI0U0eI;
  ControlBinop cBinop_CjURJwPc;
  ControlBinop cBinop_7TZbdgw6;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
